==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/GetVirtualMachineRdpFileContentsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property labName The name of the lab.
 * @property name The name of the virtual machine.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetVirtualMachineRdpFileContentsPlainArgs(
    public val labName: String,
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs =
        com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs.builder()
            .labName(labName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualMachineRdpFileContentsPlainArgs].
 */
@PulumiTagMarker
public class GetVirtualMachineRdpFileContentsPlainArgsBuilder internal constructor() {
    private var labName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the lab.
     */
    @JvmName("jjgcwgkbtskhiiyi")
    public suspend fun labName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labName = mapped
    }

    /**
     * @param value The name of the virtual machine.
     */
    @JvmName("lgdjqnfugaqhhhed")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("dunsapqrrpijwkll")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetVirtualMachineRdpFileContentsPlainArgs =
        GetVirtualMachineRdpFileContentsPlainArgs(
            labName = labName ?: throw PulumiNullFieldException("labName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/GetVirtualMachineRdpFileContentsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property labName The name of the lab.
 * @property name The name of the virtual machine.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetVirtualMachineRdpFileContentsPlainArgs(
    public val labName: String,
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs =
        com.pulumi.azurenative.devtestlab.inputs.GetVirtualMachineRdpFileContentsPlainArgs.builder()
            .labName(labName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualMachineRdpFileContentsPlainArgs].
 */
@PulumiTagMarker
public class GetVirtualMachineRdpFileContentsPlainArgsBuilder internal constructor() {
    private var labName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the lab.
     */
    @JvmName("enxjjffxbftffbpj")
    public suspend fun labName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labName = mapped
    }

    /**
     * @param value The name of the virtual machine.
     */
    @JvmName("ocdbbrmlsqatsjns")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("fabctrpfpujgvysq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetVirtualMachineRdpFileContentsPlainArgs =
        GetVirtualMachineRdpFileContentsPlainArgs(
            labName = labName ?: throw PulumiNullFieldException("labName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
